==> ovos-skill-weather-0.1.12a3.tar.gz: ovos-skill-weather-0.1.12a3/README.md <==
# <img src='https://rawgithub.com/FortAwesome/Font-Awesome/master/svgs/solid/sun.svg' card_color='#FEE255' width='50' height='50' style='vertical-align:bottom'/> Weather
Weather conditions and forecasts

## About 
Get weather conditions, forecasts, expected precipitation and more!  By default, it will tell
you about your device's configured location. You can also ask for other cities around the world. 

Current conditions and weather forecasts come from [OpenMeteo](https://open-meteo.com).

The temperature is shown in Celsius or Fahrenheit depending on the preferences set in your configuration or skill settings.
You can ask specifically for a unit that differs from your configuration.

No API key or user accounts required

## Examples 
### Current Conditions
* "What is the weather?"
* "What is the weather in Houston?"

### Daily Forecasts
* "What is the forecast tomorrow?"
* "What is the forecast in London tomorrow?"
* "What is the weather going to be like Tuesday?"
* "What is the weather for the next three days?"
* "What is the weather this weekend?"
  
### Temperatures
* "What's the temperature?"
* "What's the temperature in Paris tomorrow in Celsius?"
* "What's the high temperature tomorrow"
* "Will it be cold on Tuesday"

### Specific Weather Conditions
* "When will it rain next?"
* "How windy is it?"
* "What's the humidity?"
* "Is it going to snow?"
* "Is it going to snow in Baltimore?"
* "When is the sunset?"

## Credits
OpenVoiceOS (@OpenVoiceOS)
Mycroft AI (@MycroftAI)

## Category
**Daily**

## Tags
#weather
#forecast
#rain
#humidity
#snow
#temperature

==> ovos-skill-weather-1.0.8a2.tar.gz: ovos-skill-weather-1.0.8a2/README.md <==
[![gitlocalized ](https://gitlocalize.com/repo/9611/whole_project/badge.svg)](https://gitlocalize.com/repo/9662?utm_source=badge) [![Ask DeepWiki](https://deepwiki.com/badge.svg)](https://deepwiki.com/OpenVoiceOS/ovos-skill-weather)

# <img src='https://rawgithub.com/FortAwesome/Font-Awesome/master/svgs/solid/sun.svg' card_color='#FEE255' width='50' height='50' style='vertical-align:bottom'/> Weather
Weather conditions and forecasts

## About 
Get weather conditions, forecasts, expected precipitation and more!  By default, it will tell
you about your device's configured location. You can also ask for other cities around the world. 

Current conditions and weather forecasts come from [OpenMeteo](https://open-meteo.com).

The temperature is shown in Celsius or Fahrenheit depending on the preferences set in your configuration or skill settings.
You can ask specifically for a unit that differs from your configuration.

No API key or user accounts required

## Examples 
### Current Conditions
* "What is the weather?"
* "What is the weather in Houston?"

### Daily Forecasts
* "What is the forecast tomorrow?"
* "What is the forecast in London tomorrow?"
* "What is the weather going to be like Tuesday?"
* "What is the weather for the next three days?"
* "What is the weather this weekend?"
  
### Temperatures
* "What's the temperature?"
* "What's the temperature in Paris tomorrow in Celsius?"
* "What's the high temperature tomorrow"
* "Will it be cold on Tuesday"

### Specific Weather Conditions
* "When will it rain next?"
* "How windy is it?"
* "What's the humidity?"
* "Is it going to snow?"
* "Is it going to snow in Baltimore?"
* "When is the sunset?"

## Credits
OpenVoiceOS (@OpenVoiceOS)
Mycroft AI (@MycroftAI)

## Category
**Daily**

## Tags
#weather
#forecast
#rain
#humidity
#snow
#temperature
